@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2020, Lawrence Livermore National Security
+ * Copyright (c) 2002-2023, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -38,7 +38,7 @@
  * The spatial derivatives are computed using second-order centered differences,
  * with the data distributed over nx * ny points on a uniform spatial grid. The
  * problem is solved using the XBraid multigrid reduction in time library paired
- * with a diagonally implicit Runge-Kutta method from the ARKode ARKStep module
+ * with a diagonally implicit Runge-Kutta method from the ARKODE ARKStep module
  * using an inexact Newton method paired with the PCG or SPGMR linear solver.
  * Several command line options are available to change the problem parameters
  * and ARKStep settings. Use the flag --help for more information.
@@ -79,6 +79,9 @@ using namespace std;
 
 struct UserData
 {
+  // SUNDIALS simulation context
+  SUNContext ctx;
+
   // Diffusion coefficients in the x and y directions
   realtype kx;
   realtype ky;
@@ -265,7 +268,7 @@ static int WaitRecv(UserData *udata);
 // -----------------------------------------------------------------------------
 
 // Set the default values in the UserData structure
-static int InitUserData(UserData *udata);
+static int InitUserData(UserData *udata, SUNContext ctx);
 
 // Free memory allocated within UserData
 static int FreeUserData(UserData *udata);
@@ -328,6 +331,11 @@ int main(int argc, char* argv[])
   flag = MPI_Comm_rank(comm_w, &myid);
   if (check_flag(&flag, "MPI_Comm_rank", 1)) return 1;
 
+  // Create the SUNDIALS context object for this simulation
+  SUNContext ctx;
+  flag = SUNContext_Create(&comm_w, &ctx);
+  if (check_flag(&flag, "SUNContext_Create", 1)) return 1;
+
   // Set output process flag
   bool outproc = (myid == 0);
 
@@ -338,7 +346,7 @@ int main(int argc, char* argv[])
   // Allocate and initialize user data structure with default values. The
   // defaults may be overwritten by command line inputs in ReadInputs below.
   udata = new UserData;
-  flag = InitUserData(udata);
+  flag = InitUserData(udata, ctx);
   if (check_flag(&flag, "InitUserData", 1)) return 1;
 
   // Parse command line inputs
@@ -373,7 +381,7 @@ int main(int argc, char* argv[])
   // ------------------------
 
   // Create vector for solution
-  u = N_VNew_Parallel(udata->comm_c, udata->nodes_loc, udata->nodes);
+  u = N_VNew_Parallel(udata->comm_c, udata->nodes_loc, udata->nodes, ctx);
   if (check_flag((void *) u, "N_VNew_Parallel", 0)) return 1;
 
   // Set initial condition
@@ -389,11 +397,11 @@ int main(int argc, char* argv[])
   // ---------------------
 
   // Create linear solver
-  int prectype = (udata->prec) ? PREC_RIGHT : PREC_NONE;
+  int prectype = (udata->prec) ? SUN_PREC_RIGHT : SUN_PREC_NONE;
 
   if (udata->pcg)
   {
-    LS = SUNLinSol_PCG(u, prectype, udata->liniters);
+    LS = SUNLinSol_PCG(u, prectype, udata->liniters, ctx);
     if (check_flag((void *) LS, "SUNLinSol_PCG", 0)) return 1;
 
     if (udata->lsinfo && outproc)
@@ -407,7 +415,7 @@ int main(int argc, char* argv[])
   }
   else
   {
-    LS = SUNLinSol_SPGMR(u, prectype, udata->liniters);
+    LS = SUNLinSol_SPGMR(u, prectype, udata->liniters, ctx);
     if (check_flag((void *) LS, "SUNLinSol_SPGMR", 0)) return 1;
 
     if (udata->lsinfo && outproc)
@@ -432,7 +440,7 @@ int main(int argc, char* argv[])
   // --------------
 
   // Create integrator
-  arkode_mem = ARKStepCreate(NULL, f, ZERO, u);
+  arkode_mem = ARKStepCreate(NULL, f, ZERO, u, ctx);
   if (check_flag((void *) arkode_mem, "ARKStepCreate", 0)) return 1;
 
   // Specify tolerances
@@ -687,7 +695,9 @@ int main(int argc, char* argv[])
   delete udata;
   braid_Destroy(core);       // Free braid memory
   ARKBraid_Free(&app);       // Free interface memory
+  SUNContext_Free(&ctx);     // Free context
   flag = MPI_Finalize();     // Finalize MPI
+
   return 0;
 }
 
@@ -912,7 +922,8 @@ int MyInit(braid_App app, realtype t, braid_Vector *u_ptr)
   udata = static_cast<UserData*>(user_data);
 
   // Create new vector
-  N_Vector y = N_VNew_Parallel(udata->comm_c, udata->nodes_loc, udata->nodes);
+  N_Vector y = N_VNew_Parallel(udata->comm_c, udata->nodes_loc, udata->nodes,
+                               udata->ctx);
   flag = SUNBraidVector_New(y, u_ptr);
   if (flag != 0) return 1;
 
@@ -1575,8 +1586,11 @@ static int WaitRecv(UserData *udata)
 // -----------------------------------------------------------------------------
 
 // Initialize memory allocated within Userdata
-static int InitUserData(UserData *udata)
+static int InitUserData(UserData *udata, SUNContext ctx)
 {
+  // SUNDIALS simulation context
+  udata->ctx = ctx;
+
   // Diffusion coefficient
   udata->kx = ONE;
   udata->ky = ONE;
