@@ -1636,7 +1636,8 @@ int cvLsSolve(CVodeMem cv_mem, N_Vector b, N_Vector weight,
               N_Vector ynow, N_Vector fnow)
 {
   CVLsMem  cvls_mem;
-  realtype bnorm, deltar, delta, w_mean;
+  realtype bnorm = ZERO;
+  realtype deltar, delta, w_mean;
   int      curiter, nli_inc, retval;
 #if SUNDIALS_LOGGING_LEVEL >= SUNDIALS_LOGGING_DEBUG
   realtype resnorm;
